<?php
/*
Plugin Name: Anti-AdBlock
Plugin URI: http://omninoggin.com/projects/wordpress-plugins/anti-adblock-wordpress-plugin/
Description: This plugin displays a notification message to visitors with AdBlock on, humbly asking them to turn it off.
Version: 0.1.2
Author: Thaya Kareeson
Author URI: http://omninoggin.com
*/

/*
Copyright 2009 Thaya Kareeson (email : thaya.kareeson@gmail.com)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

class AntiAdBlock {

  var $name = 'anti_adblock'; 
  var $homepage = 'http://omninoggin.com/projects/wordpress-plugins/anti-adblock-wordpress-plugin/';
  var $displayed = false;

  function get_default_options() {
    return array(
      'can_close'    => true,
      'hide_content' => false,
      'image'        => $this->get_plugin_url() . '/images/disable_adblock.png',
      'message'      => __('<h3>Doh! It appears that you are using AdBlock software.</h3><p>Without advertisement revenue we will not be able to continue to provide quality content.  <strong>Plese consider disabling your AdBlock software (at least for this site).</strong>  Thank you in advance for your support and understanding!</p>', $this->name),
      'message_css'  => '
background-color:#fff;
border:1px solid #ccc;
color:#333;
height:auto;
left:25%;
padding:20px;
position:fixed;
top:100px;
width:50%;
z-index:10;',
      'max_nag'      => 1,
      'show_link'    => true
    );
  }

  function activate() {
    $this->upgrade_options();
  }

  function set_my_nonce() {
    $aab_options = get_option($this->name);
    $aab_options['my_nonce'] = 'a' . substr(md5(wp_create_nonce($name)), rand(0, 15), rand(5, 16));
    update_option($this->name, $aab_options);
  }

  function display() {
    if ( !$this->displayed ) {
      $aab_options = get_option($this->name);
      // strip end-of-line characters
      $style = str_replace("\n", '', $aab_options['message_css']);
      $style = str_replace("\r", '', $style);
      printf('<img src="%s/images/ad/a%s.gif" width="1" height="1">', site_url(), $aab_options['my_nonce']);
      printf('<div id="%s" style="%sdisplay:none;"></div>', $aab_options['my_nonce'], $style);
      $this->load_scripts();
      $this->displayed = true;
    }
  }

  function redirect_to_image() {
    $aab_options = get_option($this->name);
    $req_uri = $_SERVER['REQUEST_URI'];
    if ( strrpos($req_uri, $aab_options['my_nonce']) ) {
      Header( "HTTP/1.1 301 Moved Permanently" );
      Header( sprintf("Location: %s/images/ad/banner.gif", $this->get_plugin_url()) );
    }
  }

  function queue_jquery() {
    wp_enqueue_script('jquery');
  }

  function load_scripts() {
    $aab_options = get_option($this->name);

    printf('
      <link rel="stylesheet" href="%s/css/style.css" type="text/css"/>
      $this->get_plugin_url(),
      $this->get_plugin_url()
    );

    $expire_days = 365;
    
    if ( $aab_options['image'] && $aab_options['image'] != '' )
      $image_html = sprintf('<img src=\'%s\' alt=\'Adblock\' class=\'adblock_message_image\'/>', $aab_options['image']);
    else
      $image_html = '';

    if ( $aab_options['can_close'] ) {
      $close_html = sprintf('<br/><p align=\'center\'><a id=\'close-adblock-message\' href=\'#\' rel=\'nofollow\'>%s</a><br/>%s%s%s<p>',
        __('Click here to close', $this->name),
        __('You will no longer receive this message after ', $this->name),
        $aab_options['max_nag'],
        __(' visit(s) (cookies required).', $this->name)
      );
    }
    else
      $close_html = '';

    if ( $aab_options['show_link'] )
      $link_html = sprintf('<p class=\'aab_powered_by\'><a href=\'%s\' alt=\'%s\'>%s</a></p>',
        $this->homepage,
        __('Powered by Anti-AdBlock', $this->name),
        __('Powered by Anti-AdBlock', $this->name)
      );
    else
      $link_html = '';

    // generate JS
    printf('
      <script type="text/javascript">
        /* <![CDATA[ */
        function aab_get_cookie(c_name) {
          if (document.cookie.length>0) {
            c_start=document.cookie.indexOf(c_name + "=");
            if (c_start!=-1) {
              c_start=c_start + c_name.length+1;
              c_end=document.cookie.indexOf(";",c_start);
              if (c_end==-1) c_end=document.cookie.length;
              return unescape(document.cookie.substring(c_start,c_end));
            }
          }
          return "";
        }
        
        function aab_set_cookie(c_name,value,expiredays) {
          var exdate = new Date();
          exdate.setDate(exdate.getDate()+expiredays);
          document.cookie=c_name+ "=" +escape(value)+";path="+"/"+
          ((expiredays==null) ? "" : ";expires="+exdate.toGMTString());
        }

        // run when document is ready
        jQuery(document).ready(function($){
          show = false;
          aab_c_view_count = aab_get_cookie("aab_view_count");
          if(aab_c_view_count == ""){
            // create cookie
            aab_set_cookie("aab_view_count", 1, %s);

            // check if adblock is on
            if($("#%s").prev("img").css("display") == "none"){
              show = true;
            }
          }
          else{
            aab_c_view_count = parseInt(aab_c_view_count);
            if(aab_c_view_count < %s){
              show = true;
            }
            aab_set_cookie("aab_view_count", ++aab_c_view_count, %s);
          }

          if(show){
            $("#%s").css("display", "block").html("%s%s%s%s").hide().fadeIn();
        
            // bind close action to adblock message
            $("#close-adblock-message").click(function(){
              $("#%s").fadeOut();
            });
          }
        });
        /* ]]> */
      </script>',
      $expire_days,
      $aab_options['my_nonce'],
      $aab_options['max_nag'],
      $expire_days,
      $aab_options['my_nonce'],
      $image_html,
      $aab_options['message'],
      $close_html,
      $link_html,
      $aab_options['my_nonce']
    );
  }

  function update_options() {
    // new options
    $aab_new_options = stripslashes_deep($_POST['aab_options_update']);

    // current options
    $aab_current_options = get_option($this->name);

    // convert "on" to true and "off" to false for checkbox fields
    // and set defaults for fields that are left blank
    if ( isset($aab_new_options['can_close']) )
      $aab_new_options['can_close'] = true;
    else
      $aab_new_options['can_close'] = false;

    if ( isset($aab_new_options['hide_content']) )
      $aab_new_options['hide_content'] = true;
    else
      $aab_new_options['hide_content'] = false;

    if ( isset($aab_new_options['show_link']) && isset($aab_new_options['show_link']) == "on")
      $aab_new_options['show_link'] = true;
    else
      $aab_new_options['show_link'] = false;

    // set defaults if some fields that are left blank or invalid
    if ( !is_numeric($aab_new_options['max_nag']) )
      $aab_new_options['max_nag'] = $aab_current_options['max_nag'];
    elseif ( !$aab_new_options['max_nag'] || $aab_new_options['max_nag'] < 0 )
      $aab_new_options['max_nag'] = 0;

    // Update options
    foreach($aab_new_options as $key => $value) {
      $aab_current_options[$key] = $value;
    }
    update_option($this->name, $aab_current_options);
  }

  function upgrade_options() {
    $aab_options = get_option($this->name);
    if ( !$aab_options ) {
      add_option($this->name, $this->get_default_options());
    }
    else {
      $default_options = $this->get_default_options();
      foreach($default_options as $option_name => $option_value) {
        if(!isset($aab_options[$option_name])) {
          $aab_options[$option_name] = $option_value;
        }
      }
      update_option($this->name, $aab_options);
    }
    $this->set_my_nonce();
  }

  function reset_options() {
    if ( !get_option($this->name) ) {
      add_option($this->name, $this->get_default_options());
    }
    else {
      update_option($this->name, $this->get_default_options());
    }
  }

  function get_name() {
    return $this->name;
  }

  function get_plugin_dir() {
    // Pre-2.6 compatibility
    if ( !defined('WP_CONTENT_DIR') )
      define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' );
    return WP_CONTENT_DIR.'/plugins/'.plugin_basename(dirname(__FILE__));
  }

  function get_plugin_url() {
    // Pre-2.6 compatibility
    if ( !defined('WP_CONTENT_URL') )
      define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content');
    return WP_CONTENT_URL.'/plugins/'.plugin_basename(dirname(__FILE__));
  }

  function get_current_page_url() {
    $isHTTPS = (isset($_SERVER["HTTPS"]) && $_SERVER["HTTPS"] == "on");
    $port = (isset($_SERVER["SERVER_PORT"]) && ((!$isHTTPS && $_SERVER["SERVER_PORT"] != "80") || ($isHTTPS && $_SERVER["SERVER_PORT"] != "443")));
    $port = ($port) ? ':'.$_SERVER["SERVER_PORT"] : '';
    $url = ($isHTTPS ? 'https://' : 'http://').$_SERVER["SERVER_NAME"].$port.$_SERVER["REQUEST_URI"];
    return $url;
  }

  function admin_menu() {
    add_options_page('Anti-AdBlock', 'Anti-AdBlock', 'manage_options', 'anti-adblock', array($this, 'admin_page'));
  }

  function admin_page() {
    // generate nonce
    $this->set_my_nonce();
    // load text domain for translations
    load_plugin_textdomain($this->name);

    if ( isset($_POST['aab_options_update_submit']) ) {
      // if user wants to update options
      check_admin_referer($this->name);
      $this->update_options();
      printf('<div class="updated fade"><p>%s</p></div>', __('Anti-AdBlock options has been updated.', $this->name));
    }
    elseif ( isset($_POST['aab_options_upgrade_submit']) ) {
      // if user wants to upgrade options ( for new options on version upgrades )
      check_admin_referer($this->name);
      $this->upgrade_options();
      printf('<div class="updated fade"><p>%s</p></div>', __('Anti-AdBlock options has been upgraded.', $this->name));
    }
    elseif ( isset($_POST['aab_options_reset_submit']) ) {
      // if user wants to reset all options
      check_admin_referer($this->name);
      $this->reset_options();
      printf('<div class="updated fade"><p>%s</p></div>', __('Anti-AdBlock options has been reset.', $this->name));
    }

    $aab_options = get_option($this->name);
    printf('
      <div class="wrap">
        <h2>Anti-AdBlock Options</h2>
        <div>
          <a href="%s">%s</a>&nbsp;|&nbsp;
          <a href="%s">%s</a>
        </div>',
      preg_replace('/&aab-page=[^&]*/', '', $_SERVER['REQUEST_URI']),
      __('General Configurations', $this->name),
      $this->homepage,
      __('Documentation', $this->name)
    );
    if ( isset($_GET['aab-page']) ) {
      if ( $_GET['aab-page'] || !$_GET['aab-page'] ) {
        require_once('options-generic.php');
      }
    }
    else {
      require_once('options-generic.php');
    }
    printf('
      </div><!--wrap-->'
    );
  } // function admin_page()
} // class aab

$anti_adblock = new AntiAdBlock();

if ( function_exists('add_action') ) {
  add_action('admin_menu', array($anti_adblock, 'admin_menu'));
  add_action('loop_start', array($anti_adblock, 'display'));
  add_action('wp_print_scripts', array($anti_adblock, 'queue_jquery'));
  add_action('wp_head', array($anti_adblock, 'redirect_to_image'));
}

if ( function_exists('register_activation_hook') ) {
  register_activation_hook(__FILE__, array($anti_adblock, 'activate'));
}
?>
